OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Уграђена порука %s",
    "Important mail" : "Важна пошта",
    "Important" : "Важно",
    "Work" : "Посао",
    "Personal" : "Лично",
    "Later" : "После",
    "Mails" : "Поруке е-поште",
    "Mail" : "Пошта",
    "💌 A mail app for Nextcloud" : "💌 Апликација е-поште за Некстклауд",
    "Auto" : "Аутоматски",
    "Name" : "Име",
    "Mail address" : "Адреса поште",
    "Password" : "Лозинка",
    "Manual" : "Ручно",
    "IMAP Settings" : "IMAP поставке",
    "IMAP Host" : "IMAP домаћин",
    "IMAP Security" : "IMAP безбедност",
    "None" : "Ниједна",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP порт",
    "IMAP User" : "IMAP корисничко име",
    "IMAP Password" : "IMAP лозинка",
    "SMTP Settings" : "SMTP поставке",
    "SMTP Host" : "SMTP домаћин",
    "SMTP Security" : "SMTP безбедност",
    "SMTP Port" : "SMTP порт",
    "SMTP User" : "SMTP корисничко име",
    "SMTP Password" : "SMTP лозинка",
    "Connecting" : "Повезујем се",
    "Save" : "Сачувај",
    "Connect" : "Повежи се",
    "Password required" : "Потребна је лозинка",
    "Account settings" : "Поставке налога",
    "Signature" : "Потпис",
    "A signature is added to the text of new messages and replies." : "Потпис је додат на текст свих нових порука и одговора.",
    "Writing mode" : "Режим писања",
    "Preferred writing mode for new messages and replies." : "Жељени режим писања за нове поруке и одговоре.",
    "Mail server" : "Сервер е-поште",
    "Change name" : "Промени име",
    "Email address" : "Адреса е-поште",
    "Add alias" : "Додајте алиас",
    "Cancel" : "Поништи",
    "Add mail account" : "Додај налог е-поште",
    "Use Gravatar and favicon avatars" : "Користи Граватар и аватаре favicon-а",
    "Register as application for mail links" : "Региструј се као аликација за везе е-поште",
    "Show keyboard shortcuts" : "Прикажи пречице тастатуре",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволи апликацији до прикупи податке о Вашој интеракцији са њом. На основу ових података, апликација ће се прилагодити Вашим преференцама. Подаци ће бити ускладиштени само локално.",
    "From" : "Од",
    "Select account" : "Одаберите налог",
    "To" : "За",
    "Contact or email address …" : "Контакт или адреса е-поште…",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "No contacts found." : "Контакти нису нађени",
    "Subject" : "Наслов",
    "Subject …" : "Тема…",
    "This message came from a noreply address so your reply will probably not be read." : "Ова порука је стигла са адресе на којој има \"noreply\", што значи да вероватно неће бити прочитана ако одговорите на њу.",
    "The following recipients do not have a PGP key: {recipients}." : "Следећи примаоци немају PGP кључ: {recipients}.",
    "Write message …" : "Напиши поруку…",
    "Saving draft …" : "Чувам нацрт …",
    "Draft saved" : "Нацрт сачуван",
    "Upload attachment" : "Закачи прилог",
    "Add attachment from Files" : "Додај прилог из фајлова",
    "Add link" : "Додај везу",
    "Enable formatting" : "Укључи форматирање",
    "Encrypt message with Mailvelope" : "Шифруј поруку са Mailvelope-ом",
    "Tomorrow morning" : "Сутра ујутру",
    "Tomorrow afternoon" : "Сутра после подне",
    "Monday morning" : "Понедељак ујутру",
    "Enter a date" : "Унеси датум",
    "Send" : "Пошаљи",
    "Choose a file to add as attachment" : "Изаберите фајл за прилог",
    "Choose a file to share as a link" : "Одаберите фајл који желите да поделите као везу",
    "No message found yet" : "Још нема порука",
    "Set up an account" : "Подесите налог",
    "Plain text" : "Обичан текст",
    "Rich text" : "Обогаћени текст",
    "No messages" : "Нема порука",
    "Draft: " : "Нацрт: ",
    "Unfavorite" : "Није омиљено",
    "Favorite" : "Омиљени",
    "Read" : "Читање",
    "Mark not spam" : "Означи да није спам",
    "Mark as spam" : "Означи као спам",
    "Unselect" : "Уклони избор",
    "Select" : "Обележи",
    "Edit tags" : "Уреди ознаке",
    "More actions" : "Још акција",
    "Blind copy recipients only" : "Само примаоци невидљиве копије",
    "Forward" : "Проследи",
    "Load more" : "Учитај још",
    "Report this bug" : "Пријави ову грешку",
    "All day" : "Цео дан",
    "Create" : "Направи",
    "Could not create event" : "Не могу да креирам догађај",
    "Comment" : "Коментар",
    "Accept" : "Прихвати",
    "Decline" : "Одбиј",
    "Could not open mailbox" : "Не могу да отворим сандуче",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Индексирам Ваше поруке. Ово може потрајати на већим сандучетима.",
    "Choose" : "Изаберите",
    "Important info" : "Важна информација",
    "Other" : "Остало",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Поруке ће аутоматски бити означаване као важне на основу тога које поруке одговарати или означавате као важне. У почетку ћете можда морати ручно да мењате важност да научите систем, али ће се он поправљати временом.",
    "Reply" : "Одговори",
    "Reply to sender only" : "Одговори само пошиљаоцу",
    "View source" : "Погледај изворни код",
    "Download thread data for debugging" : "Преузми податке нити за потребе отклањања грешака",
    "Message source" : "Изворни код поруке",
    "Import into calendar" : "Увези у календар",
    "Download attachment" : "Скини прилог",
    "Save to Files" : "Сачувај у фајлове",
    "Unnamed" : "Неименовано",
    "Embedded message" : "Уграђена порука",
    "Choose a folder to store the attachment in" : "Изаберите фасциклу за смештање прилога",
    "Save all to Files" : "Сачувај све у фајлове",
    "Choose a folder to store the attachments in" : "Одаберите фасциклу за смештање прилога",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Ова порука је шифрована PGP-ом. Инсталирајте Mailvelope да је дешифрујете.",
    "The images have been blocked to protect your privacy." : "Слике су блокиране да заштите Вашу приватност.",
    "Show images" : "Прикажи слике",
    "Message frame" : "Оквир поруке",
    "Quoted text" : "Цитирани текст",
    "Move" : "Помери",
    "Moving" : "Померам",
    "Quota" : "Квота",
    "Saving" : "Чувам",
    "Move up" : "Помери нагоре",
    "Move down" : "Помери надоле",
    "Remove account" : "Уклони налог",
    "Loading …" : "Учитавање…",
    "Not supported by the server" : "Сервер не подржава ово",
    "{usage} of {limit} used" : "{usage} од {limit} искоришћено",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} налог и кеширани подаци е-поште ће бити уклоњени из Некстклауда, али не и са Вашег е-мејл провајдера.",
    "Remove account {email}" : "Уклони налог {email}",
    "Remove {email}" : "Уклони {email}",
    "Mark all as read" : "Означи све као прочитано",
    "Mark all messages of this mailbox as read" : "Означи све поруке у овом сандучету прочитаним",
    "Edit name" : "Измени име",
    "Clear cache" : "Очисти кеш",
    "Clear locally cached data, in case there are issues with synchronization." : "Очисти локално кеширане податке, у случају да има проблема са синхронизацијом.",
    "Subscribed" : "Претплаћен",
    "Sync in background" : "Синхронизуј у позадини",
    "An error occurred, unable to rename the mailbox." : "Догодила се грешка, не могу да преименујем сандуче.",
    "_{total} message_::_{total} messages_" : ["{total} порука","{total} поруке","{total} порука"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочитана од {total}","{unread} непрочитане од {total}","{unread} непрочитаних од {total}"],
    "New message" : "Нова порука",
    "Error sending your message" : "Грешка приликом слања поруке",
    "Go back" : "Иди назад",
    "Retry" : "Покушај поново",
    "Uploading attachments …" : "Отпремам прилоге …",
    "Sending …" : "Шаљем …",
    "No message selected" : "Није одабрана ниједна порука",
    "Message" : "Порука",
    "Delete" : "Избриши",
    "Copy to clipboard" : "Копирај у оставу",
    "Add" : "Додај",
    "Tags" : "Ознаке",
    "Select tags" : "Одабери ознаку",
    "Clear" : "Очисти",
    "Search" : "Претражи",
    "Date" : "Датум",
    "Disabled" : "Искључено",
    "Enabled" : "укључено",
    "Custom" : "Прилагођено",
    "Signature …" : "Потпис…",
    "Save signature" : "Сачувај потпис",
    "Set" : "Постави",
    "Unset" : "Уклони",
    "Add tag" : "Додајте ознаку",
    "Tag already exists" : "Ознака већ постоји",
    "Not found" : "Није нађено",
    "Could not load your message thread" : "Не могу да учитам ток дискусије поруке",
    "Mark as unread" : "Означи као непрочитано",
    "Mark as read" : "Означи као прочитано",
    "Remove" : "Уклони",
    "Untitled event" : "Неименовани догађај",
    "Import into {calendar}" : "Увези у {calendar}",
    "Event imported into {calendar}" : "Догађај увезен у {calendar}",
    "Airplane" : "Авион",
    "Reservation {id}" : "Резервација {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Лет {flightNr} са аеродрома {depAirport} на {arrAirport}",
    "Train" : "Воз",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} са станице {depStation} до станице {arrStation}",
    "Train from {depStation} to {arrStation}" : "Воз са станице {depStation} до станице {arrStation}",
    "Mail app" : "Апликације е-поште",
    "The mail app allows users to read mails on their IMAP accounts." : "Апликације е-поште дозвољава корисницима да читају пошту на њиховим IMAP налозима.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Овде можете наћи подешавања на нивоу целе инстанце. Конкретна подешавања корисника се налазе баш у апликацији (доњи леви угао).",
    "Reset" : "Ресетуј",
    "Client ID" : "ID клијента",
    "Client secret" : "Тајна клијента",
    "Email: {email}" : "Мејл: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} на {host}:{port} ({ssl} шифровање)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} на {host}:{port} ({ssl} шифровање)",
    "General" : "Опште",
    "IMAP" : "IMAP",
    "User" : "Корисник",
    "Host" : "Домаћин",
    "Port" : "Порт",
    "SMTP" : "SMTP",
    "With the settings above, the app will create account settings in the following way:" : "Уз поставке изнад, апликација ће креирати поставке налога на следећи начин:",
    "E-mail address" : "Адреса е-поште",
    "Valid until" : "Важи до",
    "Certificate" : "Сертификат",
    "Back" : "Назад",
    "Submit" : "Пошаљи",
    "Keyboard shortcut" : "Пречица тастатуре",
    "Keyboard shortcuts" : "Пречице на тастатури",
    "Speed up your Mail experience with these quick shortcuts." : "Убрзајте рад са Поштом са овим брзим пречицама.",
    "Compose new message" : "Напиши нову поруку",
    "Newer message" : "Новије поруке",
    "Older message" : "Старије поруке",
    "Toggle star" : "Мењај озвезданост",
    "Toggle unread" : "Означи као прочитано/непрочитано",
    "Archive" : "Архива",
    "Refresh" : "Освежи",
    "Account connected" : "Налог повезан",
    "Connect your mail account" : "Повежи се на налог е-поште",
    "Itinerary for {type} is not supported yet" : "Итеринер за {type} још није подржан",
    "All" : "Све",
    "Drafts" : "Недовршене",
    "Favorites" : "Омиљене",
    "Priority inbox" : "Приоритетно сандуче",
    "All inboxes" : "Сва сандучета",
    "Inbox" : "Долазно сандуче",
    "Junk" : "Отпад",
    "Sent" : "Послате",
    "Trash" : "Смеће",
    "Error while sharing file" : "Грешка приликом дељења фајла",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n порука\nод {from}","%n поруке\nод {from}","%n порука\nод {from}"],
    "Nextcloud Mail" : "Некстклауд Пошта",
    "Message sent" : "Порука послата",
    "Could not load {tag}{name}{endtag}" : "Не могу да учитам {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Десио се проблем приликом учитавања {tag}{name}{endtag}",
    "Could not load your message" : "Неуспело учитавање поруке",
    "Could not load the desired message" : "Неуспело учитавање жељене поруке",
    "Could not load the message" : "Неуспело учитавање поруке",
    "Error loading message" : "Грешка при учитавању поруке",
    "Forwarding to %s" : "Прослеђивање на %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Кликните овде ако нисте аутоматски преусмерени у наредних неколико секунди.",
    "Redirect" : "Преусмеравање",
    "The link leads to %s" : "Веза води на %s",
    "Continue to %s" : "Настави на %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
